@@ -1,25 +1,6 @@
-/*
- * Portions created by Alan Antonuk are Copyright (c) 2013-2014 Alan Antonuk.
- * All Rights Reserved.
- *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
- */
+// Copyright 2007 - 2021, Alan Antonuk and the rabbitmq-c contributors.
+// SPDX-License-Identifier: mit
+
 #ifndef AMQP_TIMER_H
 #define AMQP_TIMER_H
 
@@ -53,7 +34,9 @@
  * - UINT64_MAX: means 'at infinity', its mean for polls with an infinite
  *   timeout
  */
-typedef struct amqp_time_t_ { uint64_t time_point_ns; } amqp_time_t;
+typedef struct amqp_time_t_ {
+  uint64_t time_point_ns;
+} amqp_time_t;
 
 /* Gets a monotonic timestamp. This will return 0 if the underlying call to the
  * system fails.
@@ -62,7 +45,6 @@ uint64_t amqp_get_monotonic_timestamp(void);
 
 /* Get a amqp_time_t that is timeout from now.
  * If timeout is NULL, an amqp_time_infinite() is created.
- * If timeout = {0, 0}, an amqp_time_immediate() is created.
  *
  * Returns AMQP_STATUS_OK on success.
  * AMQP_STATUS_INVALID_PARAMETER if timeout is invalid
@@ -80,9 +62,6 @@ int amqp_time_from_now(amqp_time_t *time, const struct timeval *timeout);
  */
 int amqp_time_s_from_now(amqp_time_t *time, int seconds);
 
-/* Create an immediate amqp_time_t */
-amqp_time_t amqp_time_immediate(void);
-
 /* Create an infinite amqp_time_t */
 amqp_time_t amqp_time_infinite(void);
 
